<img src="https://curvenote.dev/images/logo.png" width="200" />

# Curvenote Template

`curvenote-template` has been renamed to `JTEX` 🚀

You can find the latest version of this CLI tool for data driven LaTeX documents on [on github](https://github.com/curvenote/jtex) and [on pypi](https://pypi.org/project/jtex/).
